@@ -54,6 +54,7 @@
 #include <gnome.h>
 
 #include <gconf/gconf-client.h>
+#include <nautilus-burn-drive-selection.h>
 
 #include "gnome-cd.h"
 #include "preferences.h"
@@ -70,7 +71,6 @@ do_device_changed (GnomeCDPreferences *prefs,
 	if (prefs->device != NULL) {
 		g_free (prefs->device);
 	}
-
 	prefs->device = g_strdup (device);
 	if (prefs->gcd->cdrom != NULL &&
 	    prefs->gcd->device_override == NULL) {
@@ -90,6 +90,7 @@ do_device_changed (GnomeCDPreferences *prefs,
 		}
 		
 		cd_selection_stop (prefs->gcd->cd_selection);
+		prefs->gcd->last_status->cd = GNOME_CDROM_STATUS_NOTHING;
 		prefs->gcd->cd_selection = cd_selection_start (prefs->device);
 	}
 }
@@ -259,7 +260,6 @@ typedef struct _PropertyDialog {
 	GtkWidget *window;
 
 	GtkWidget *cd_device;
-	GtkWidget *apply;
 	
 	GtkWidget *start_play;
 	GtkWidget *start_stop;
@@ -329,74 +329,23 @@ prefs_destroy_cb (GtkDialog *dialog,
 }
 
 static void
-apply_clicked_cb (GtkWidget *apply,
-		  PropertyDialog *pd)
+device_changed_cb (NautilusBurnDriveSelection *bcs,
+		   const char *device_path,
+		   PropertyDialog *pd)
 {
-	const char *new_device;
 	GnomeCDRom *dummy;
 
-	new_device = gtk_entry_get_text (GTK_ENTRY (pd->cd_device));
-	
-	if (!new_device)
+	if (!device_path)
 		return;
 
 	if (pd->gcd->preferences->device &&
-	    strcmp (new_device, pd->gcd->preferences->device) == 0)
+	    strcmp (device_path, pd->gcd->preferences->device) == 0)
 		return;
 	
-	gconf_client_set_string (client, "/apps/gnome-cd/device", new_device, NULL);
-	gtk_widget_set_sensitive (pd->apply, FALSE);
+	gconf_client_set_string (client, "/apps/gnome-cd/device", device_path, NULL);
 
-	dummy = gnome_cdrom_new (new_device, GNOME_CDROM_UPDATE_NEVER, NULL);
-	if (dummy == NULL) {
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (pd->window),
-						   GTK_RESPONSE_CLOSE,
-						   FALSE);
-	} else {
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (pd->window),
-						   GTK_RESPONSE_CLOSE,
-						   TRUE);
-		g_object_unref (G_OBJECT (dummy));
-	}
-
-}
-
-static void
-device_changed_cb (GtkWidget *entry,
-		   PropertyDialog *pd)
-{
-	const char *new_device;
-
-	new_device = gtk_entry_get_text (GTK_ENTRY (entry));
-	if (new_device == NULL || *new_device == 0) {
-		gtk_widget_set_sensitive (pd->apply, FALSE);
-		return;
-	}
-
-	if (pd->gcd->preferences->device != NULL) {
-		if (strcmp (new_device, pd->gcd->preferences->device) == 0) {
-			gtk_widget_set_sensitive (pd->apply, FALSE);
-			return;
-		}
-	}
-
-	gtk_widget_set_sensitive (pd->apply, TRUE);
-}
-
-static void
-change_device_widget (GConfClient *_client,
-		      guint cnxn,
-		      GConfEntry *entry,
-		      gpointer user_data)
-{
-	PropertyDialog *pd = user_data;
-	GConfValue *value = gconf_entry_get_value (entry);
-	
-	g_signal_handlers_block_matched (G_OBJECT (pd->cd_device), G_SIGNAL_MATCH_FUNC,
-					 0, 0, NULL, G_CALLBACK (device_changed_cb), pd);
-	gtk_entry_set_text (GTK_ENTRY (pd->cd_device), gconf_value_get_string (value));
-	g_signal_handlers_unblock_matched (G_OBJECT (pd->cd_device), G_SIGNAL_MATCH_FUNC,
-					   0, 0, NULL, G_CALLBACK (device_changed_cb), pd);
+	dummy = gnome_cdrom_new (device_path, GNOME_CDROM_UPDATE_NEVER, NULL);
+	g_object_unref (dummy);
 }
 
 static void
@@ -613,8 +562,7 @@ make_title_label (const char *text)
 }
 
 GtkWidget *
-preferences_dialog_show (GnomeCD *gcd,
-			 gboolean only_device)
+preferences_dialog_show (GnomeCD *gcd)
 {
 	PropertyDialog *pd;
 	GtkWindow *windy;
@@ -642,25 +590,18 @@ preferences_dialog_show (GnomeCD *gcd,
 						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 	gtk_window_set_default_size (GTK_WINDOW (pd->window), 390, 315);
+	gtk_container_set_border_width (GTK_CONTAINER (pd->window), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (pd->window)->vbox), 2);
 	
-	if (only_device == FALSE) {
-		g_signal_connect (G_OBJECT (pd->window), "response",
-				  G_CALLBACK (prefs_response_cb), pd);
-	} else {
-		/* A bit of a cheat:
-		   but if we're only setting the device,
-		   that means the device is wrong... */
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (pd->window),
-						   GTK_RESPONSE_CLOSE,
-						   FALSE);
-	}
+	g_signal_connect (G_OBJECT (pd->window), "response",
+			  G_CALLBACK (prefs_response_cb), pd);
 
 	g_signal_connect (G_OBJECT (pd->window), "destroy",
 			  G_CALLBACK (prefs_destroy_cb), pd);
 
 	/* General */
 	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_widget_show (vbox);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pd->window)->vbox), vbox);
 	
@@ -669,7 +610,7 @@ preferences_dialog_show (GnomeCD *gcd,
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, FALSE, FALSE, 0);
 	gtk_widget_show (inner_vbox);
 	
-	label = make_title_label (_("CD Player De_vice:"));
+	label = make_title_label (_("CD Player"));
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -681,31 +622,21 @@ preferences_dialog_show (GnomeCD *gcd,
 	inner_hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox), inner_hbox, TRUE, TRUE, 0);
 	
-	pd->cd_device = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (pd->cd_device), gcd->preferences->device);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->cd_device);
-	add_paired_relations (label, ATK_RELATION_LABEL_FOR,
-			      pd->cd_device, ATK_RELATION_LABELLED_BY);
+	label = gtk_label_new_with_mnemonic (_("_Device:"));
+	gtk_box_pack_start (GTK_BOX (inner_hbox), label, FALSE, FALSE, 0);
 	
-	g_signal_connect (G_OBJECT (pd->cd_device), "changed",
+	pd->cd_device = nautilus_burn_drive_selection_new ();
+	nautilus_burn_drive_selection_set_device (NAUTILUS_BURN_DRIVE_SELECTION (pd->cd_device), gcd->preferences->device);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->cd_device);
+	
+	g_signal_connect (pd->cd_device, "device_changed",
 			  G_CALLBACK (device_changed_cb), pd);
-	g_signal_connect (G_OBJECT (pd->cd_device), "activate",
-			  G_CALLBACK (apply_clicked_cb), pd);
 	gtk_box_pack_start (GTK_BOX (inner_hbox), pd->cd_device, TRUE, TRUE, 0);
 	
-	pd->apply = gtk_button_new_with_mnemonic (_("_Apply change"));
-	gtk_widget_set_sensitive (pd->apply, FALSE);
-	g_signal_connect (G_OBJECT (pd->apply), "clicked",
-			  G_CALLBACK (apply_clicked_cb), pd);
-	gtk_box_pack_start (GTK_BOX (inner_hbox), pd->apply, FALSE, FALSE, 0);
-
-	pd->device_id = gconf_client_notify_add (client,
-						 "/apps/gnome-cd/device",
-						 change_device_widget, pd, NULL, NULL);
 	inner_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, FALSE, FALSE, 0);
 
-	label = make_title_label (_("CD Player Behaviour:"));
+	label = make_title_label (_("Behavior"));
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -715,11 +646,11 @@ preferences_dialog_show (GnomeCD *gcd,
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
 	
 	/* left side */
-	action_vbox = gtk_vbox_new (TRUE, 0);
+	action_vbox = gtk_vbox_new (TRUE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox), action_vbox, TRUE, TRUE, 0);
 
-	pd->start_play = gtk_check_button_new_with_mnemonic (_("Start _playing CD when CD Player starts"));
-	add_description (pd->start_play, _("Start playing CD when CD Player starts"));
+	pd->start_play = gtk_check_button_new_with_mnemonic (_("Start _playback when CD Player starts"));
+	add_description (pd->start_play, _("Start playback when CD Player starts"));
 	if (gcd->preferences->start_play) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->start_play), TRUE);
 	}
@@ -744,15 +675,11 @@ preferences_dialog_show (GnomeCD *gcd,
 					       "/apps/gnome-cd/on-stop-eject",
 					       change_stop_widget, pd, NULL, NULL);
 	
-	if (only_device == TRUE) {
-		gtk_widget_set_sensitive (hbox, FALSE);
-	}
-
 	inner_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (inner_vbox);
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, TRUE, TRUE, 0);
 
-	label = make_title_label (_("_Available Themes:"));
+	label = make_title_label (_("Themes"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
@@ -764,6 +691,16 @@ preferences_dialog_show (GnomeCD *gcd,
 	spacer = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
 	
+	label = gtk_label_new_with_mnemonic (_("_Select a theme:"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
+	gtk_widget_show (hbox);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
+	
 	pd->theme_list = gtk_tree_view_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->theme_list);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (pd->theme_list), FALSE);
@@ -789,6 +726,7 @@ preferences_dialog_show (GnomeCD *gcd,
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(sw), GTK_SHADOW_IN);
 	gtk_container_add (GTK_CONTAINER (sw), pd->theme_list);
 	gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
 
@@ -797,10 +735,6 @@ preferences_dialog_show (GnomeCD *gcd,
 						change_theme_selection_widget, pd, NULL, NULL);
 	gtk_widget_show_all (pd->window);
 
-	if (only_device == TRUE) {
-		gtk_widget_set_sensitive (sw, FALSE);
-	}
-	
 	return pd->window;
 }
 
